# Izza 

Izza is my personal data science and machine learning toolbox.

There is mainly personal function for data visualisation: 

| function name | presentation |
|--|--|
| pca_visualisation| a pca visualtion (2 components) |
| missingData| a tables showing missing data by features |
| camembert_plot| a camembert plot |
| kohohen maps|a kohohen maps with percentage of target class by neuron|
| activation_frequencies| activation frequencies for a kohohen map |

There is methods to do model evaluation : 


| function name | presentation |
|--|--|
| fun_precision | precision at a determined percentage using predicted probabilities |
| fun_recall| recall at a determined percentage using predicted probabilities |
| f_macro_score | scorer allowing to find whether some clusters contain enough precision and recall for the target class|
| precision_macro_score| scorer allowing to find whether some clusters contain enough precision for the target class |
| recall_macro_score | scorer allowing to find whether some clusters contain enough recall for the target class|
| viable_clusters| function allowing to know the interessing clusters found using the f_macro score.|



